@@ -63,7 +63,7 @@ def build_in_progress(image_id: str, region="us-east-1"):
 
 
 @task
-def build_complate(image_id: str, output_file: str, region="us-east-1"):
+def build_complete(image_id: str, output_file: str, region="us-east-1"):
     contents = shell_task.run(
         command=f'pcluster describe-image --image-id {image_id} --region {region} > {output_file}'
     )
@@ -73,7 +73,7 @@ def build_complate(image_id: str, output_file: str, region="us-east-1"):
 def main(image_id: str, output_file: str, region: str = "us-east-1"):
     with Flow("pcluster-build-ami-flow") as flow:
         build_in_progress(image_id=image_id, region=region)
-        build_complate(image_id=image_id, region=region, output_file=output_file)
+        build_complete(image_id=image_id, region=region, output_file=output_file)
     flow_state = flow.run()
     return flow_state
 
